@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2012-2013  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2012-2020  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,6 +32,7 @@
 
 #include "cut-logger.h"
 #include "cut-enum-types.h"
+#include "cut-glib-compatible.h"
 #include "../gcutter/gcut-marshalers.h"
 
 #define DEFAULT_KEY "default"
@@ -44,9 +45,8 @@
     (CUT_LOG_ITEM_TIME)
 
 #define CUT_LOGGER_GET_PRIVATE(obj)                     \
-    (G_TYPE_INSTANCE_GET_PRIVATE((obj),                 \
-                                 CUT_TYPE_LOGGER,       \
-                                 CutLoggerPrivate))
+    ((CutLoggerPrivate *)                               \
+     cut_logger_get_instance_private(CUT_LOGGER(obj)))
 
 #define INTERNAL_INTERESTING_LOG_LEVEL                          \
     (cut_logger_get_interesting_level(singleton_cut_logger))
@@ -91,7 +91,7 @@ static gint signals[LAST_SIGNAL] = {0};
 
 static CutLogger *singleton_cut_logger = NULL;
 
-G_DEFINE_TYPE(CutLogger, cut_logger, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE(CutLogger, cut_logger, G_TYPE_OBJECT);
 
 static void dispose        (GObject         *object);
 static void set_property   (GObject         *object,
@@ -149,8 +149,6 @@ cut_logger_class_init (CutLoggerClass *klass)
                      G_TYPE_NONE, 7,
                      G_TYPE_STRING, CUT_TYPE_LOG_LEVEL_FLAGS, G_TYPE_STRING,
                      G_TYPE_UINT, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_STRING);
-
-    g_type_class_add_private(gobject_class, sizeof(CutLoggerPrivate));
 }
 
 static void
@@ -530,12 +528,15 @@ check_cut_debug (CutLogLevelFlags level)
 }
 
 void
-cut_logger_default_log_handler (CutLogger *logger, const gchar *domain,
-                                   CutLogLevelFlags level,
-                                   const gchar *file, guint line,
-                                   const gchar *function,
-                                   GTimeVal *time_value, const gchar *message,
-                                   gpointer user_data)
+cut_logger_default_log_handler (CutLogger *logger,
+                                const gchar *domain,
+                                CutLogLevelFlags level,
+                                const gchar *file,
+                                guint line,
+                                const gchar *function,
+                                GDateTime *timestamp,
+                                const gchar *message,
+                                gpointer user_data)
 {
     CutLoggerPrivate *priv;
     CutLogLevelFlags target_level;
@@ -578,7 +579,7 @@ cut_logger_default_log_handler (CutLogger *logger, const gchar *domain,
     if (target_item & CUT_LOG_ITEM_TIME) {
         gchar *time_string;
 
-        time_string = g_time_val_to_iso8601(time_value);
+        time_string = g_date_time_format_iso8601(timestamp);
         g_string_append_printf(log, "[%s]", time_string);
         g_free(time_string);
     }
@@ -668,14 +669,14 @@ cut_logger_log_va_list (CutLogger *logger,
                         const gchar *file, guint line, const gchar *function,
                         const gchar *format, va_list args)
 {
-    GTimeVal time_value;
+    GDateTime *timestamp;
     gchar *message;
 
-    g_get_current_time(&time_value);
-
+    timestamp = g_date_time_new_now_local();
     message = g_strdup_vprintf(format, args);
     g_signal_emit(logger, signals[LOG], 0,
-                  domain, level, file, line, function, &time_value, message);
+                  domain, level, file, line, function, timestamp, message);
+    g_date_time_unref(timestamp);
     g_free(message);
 }
 
