@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007-2009  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2007-2011  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,15 +28,6 @@
 #include <errno.h>
 #include <sys/types.h>
 
-#ifdef HAVE_IO_H
-#  include <io.h>
-#  define pipe(phandles) _pipe(phandles, 4096, _O_BINARY)
-#else
-#  ifdef HAVE_UNISTD_H
-#    include <unistd.h>
-#  endif
-#endif
-
 #ifdef HAVE_SYS_WAIT_H
 #  include <sys/wait.h>
 #endif
@@ -49,6 +40,13 @@
 #include "cut-experimental.h"
 #include "cut-utils.h"
 
+#ifdef G_OS_WIN32
+#  include <io.h>
+#  define pipe(phandles) _pipe(phandles, 4096, _O_BINARY)
+#else
+#  include <unistd.h>
+#endif
+
 #define CUT_PROCESS_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CUT_TYPE_PROCESS, CutProcessPrivate))
 
 typedef struct _CutProcessPrivate	CutProcessPrivate;
@@ -331,13 +329,12 @@ cut_process_get_pid (CutProcess *process)
 static gchar *
 read_from_channel (GIOChannel *source)
 {
-    GIOStatus status;
     gsize bytes_read;
     gchar *buffer = NULL;
 
-    status = g_io_channel_read_to_end(source, &buffer,
-                                      &bytes_read,
-                                      NULL);
+    g_io_channel_read_to_end(source, &buffer,
+                             &bytes_read,
+                             NULL);
     return buffer;
 }
 #endif
