@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007-2012  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2007-2020  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -53,6 +53,7 @@
 #include "cut-process.h"
 #include "cut-backtrace-entry.h"
 #include "cut-utils.h"
+#include "cut-glib-compatible.h"
 
 #define CUT_SIGNAL_EXPLICIT_JUMP G_MININT
 
@@ -174,7 +175,7 @@ taken_list_free (TakenList *taken_list)
     g_slice_free(TakenList, taken_list);
 }
 
-static GStaticPrivate current_context_private;
+static GPrivate current_context_private = G_PRIVATE_INIT(NULL);
 
 static void dispose        (GObject         *object);
 static void set_property   (GObject         *object,
@@ -513,20 +514,17 @@ cut_test_context_error_quark (void)
 void
 cut_test_context_current_init (void)
 {
-    g_static_private_init(&current_context_private);
 }
 
 void
 cut_test_context_current_quit (void)
 {
-    g_static_private_free(&current_context_private);
-}
-
-static void
-contexts_free (gpointer data)
-{
-    GPtrArray *contexts = data;
-    g_ptr_array_free(contexts, TRUE);
+    GPtrArray *contexts;
+    contexts = g_private_get(&current_context_private);
+    if (contexts) {
+        g_ptr_array_free(contexts, TRUE);
+    }
+    g_private_set(&current_context_private, NULL);
 }
 
 void
@@ -540,10 +538,10 @@ cut_test_context_current_push (CutTestContext *context)
         context = cut_test_context_new_sub(context);
     }
 
-    contexts = g_static_private_get(&current_context_private);
+    contexts = g_private_get(&current_context_private);
     if (!contexts) {
         contexts = g_ptr_array_new();
-        g_static_private_set(&current_context_private, contexts, contexts_free);
+        g_private_set(&current_context_private, contexts);
     }
     g_ptr_array_add(contexts, context);
 }
@@ -554,7 +552,7 @@ cut_test_context_current_pop (void)
     GPtrArray *contexts;
     CutTestContext *context = NULL;
 
-    contexts = g_static_private_get(&current_context_private);
+    contexts = g_private_get(&current_context_private);
     if (contexts) {
         context = g_ptr_array_index(contexts, contexts->len - 1);
         g_ptr_array_remove_index(contexts, contexts->len - 1);
@@ -568,7 +566,7 @@ cut_test_context_current_peek (void)
 {
     GPtrArray *contexts;
 
-    contexts = g_static_private_get(&current_context_private);
+    contexts = g_private_get(&current_context_private);
     if (contexts)
         return g_ptr_array_index(contexts, contexts->len - 1);
     else
@@ -825,7 +823,7 @@ cut_test_context_get_n_data (CutTestContext *context)
 }
 
 void
-cut_test_context_set_jump (CutTestContext *context, jmp_buf *buffer)
+cut_test_context_set_jump_buffer (CutTestContext *context, jmp_buf *buffer)
 {
     CutTestContextPrivate *priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
 
@@ -833,7 +831,7 @@ cut_test_context_set_jump (CutTestContext *context, jmp_buf *buffer)
 }
 
 jmp_buf *
-cut_test_context_get_jump (CutTestContext *context)
+cut_test_context_get_jump_buffer (CutTestContext *context)
 {
     return CUT_TEST_CONTEXT_GET_PRIVATE(context)->jump_buffer;
 }
@@ -857,7 +855,13 @@ cut_test_context_long_jump (CutTestContext *context)
     }
 
     if (cut_test_context_in_user_message_jump(context) || same_thread_p) {
-        longjmp(*(priv->jump_buffer), CUT_SIGNAL_EXPLICIT_JUMP);
+        if (priv->test) {
+            cut_test_long_jump(priv->test,
+                               priv->jump_buffer,
+                               CUT_SIGNAL_EXPLICIT_JUMP);
+        } else {
+            longjmp(*(priv->jump_buffer), CUT_SIGNAL_EXPLICIT_JUMP);
+        }
     } else {
         if (priv->parent && cut_test_context_is_failed(context)) {
             cut_test_context_set_failed(priv->parent, TRUE);
@@ -1199,6 +1203,21 @@ cut_test_context_take_g_string (CutTestContext *context,
                                             (CutDestroyFunction) cut_test_context_g_string_free);
 }
 
+static void
+cut_test_context_g_bytes_unref (GBytes *bytes)
+{
+    g_bytes_unref(bytes);
+}
+
+GBytes *
+cut_test_context_take_g_bytes (CutTestContext *context,
+                               GBytes         *bytes)
+{
+    return (GBytes *)cut_test_context_take(context,
+                                           bytes,
+                                           (CutDestroyFunction) cut_test_context_g_bytes_unref);
+}
+
 int
 cut_test_context_trap_fork (CutTestContext *context)
 {
