@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2009-2010  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2009-2019  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,8 +21,7 @@
 #  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
-#include "gcut-data-helper.h"
-#include "gcut-assertions-helper.h"
+#include <gcutter.h>
 
 #define DEFINE_GETTER_HELPER(type_name, type)                           \
 type                                                                    \
@@ -42,9 +41,13 @@ gcut_data_get_ ## type_name ## _helper (gconstpointer data,             \
     return value;                                                       \
 }
 
+DEFINE_GETTER_HELPER(char, gchar)
 DEFINE_GETTER_HELPER(string, const gchar *)
-DEFINE_GETTER_HELPER(uint, guint)
 DEFINE_GETTER_HELPER(int, gint)
+DEFINE_GETTER_HELPER(uint, guint)
+DEFINE_GETTER_HELPER(int64, gint64)
+DEFINE_GETTER_HELPER(uint64, guint64)
+DEFINE_GETTER_HELPER(size, gsize)
 #define gcut_data_get_data_type_helper gcut_data_get_type_helper
 DEFINE_GETTER_HELPER(data_type, GType)
 #undef gcut_data_get_data_type_helper
@@ -53,6 +56,8 @@ DEFINE_GETTER_HELPER(enum, gint)
 DEFINE_GETTER_HELPER(pointer, gconstpointer)
 DEFINE_GETTER_HELPER(boxed, gconstpointer)
 DEFINE_GETTER_HELPER(object, gpointer)
+DEFINE_GETTER_HELPER(boolean, gboolean)
+DEFINE_GETTER_HELPER(double, gdouble)
 
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
