@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2019  Sutou Kouhei <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,17 +27,15 @@
 #endif
 #include <signal.h>
 
-#include <glib.h>
+#include <gcutter.h>
+#include "gcut-marshalers.h"
+#include <cutter/cut-utils.h>
+
 #include <glib/gstdio.h>
 #include <gmodule.h>
 
-#include "gcut-io.h"
-#include "gcut-egg.h"
-#include "gcut-marshalers.h"
-#include "cut-utils.h"
-
-#define GCUT_EGG_GET_PRIVATE(obj)                                     \
-    (G_TYPE_INSTANCE_GET_PRIVATE((obj), GCUT_TYPE_EGG, GCutEggPrivate))
+#define GCUT_EGG_GET_PRIVATE(obj)                                       \
+    ((GCutEggPrivate *)gcut_egg_get_instance_private(GCUT_EGG(obj)))
 
 typedef struct _WatchOutputData
 {
@@ -90,7 +88,7 @@ enum
 
 static guint signals[LAST_SIGNAL] = {0};
 
-G_DEFINE_TYPE(GCutEgg, gcut_egg, G_TYPE_OBJECT)
+G_DEFINE_TYPE_WITH_PRIVATE(GCutEgg, gcut_egg, G_TYPE_OBJECT)
 
 static void dispose        (GObject         *object);
 static void set_property   (GObject         *object,
@@ -225,8 +223,6 @@ gcut_egg_class_init (GCutEggClass *klass)
                        NULL, NULL,
                        g_cclosure_marshal_VOID__POINTER,
                        G_TYPE_NONE, 1, G_TYPE_POINTER);
-
-    g_type_class_add_private(gobject_class, sizeof(GCutEggPrivate));
 }
 
 static void
@@ -342,7 +338,8 @@ dispose (GObject *object)
                                             &is_timeout);
             while (!is_timeout && priv->process_watch_id > 0 && priv->pid > 0)
                 g_main_context_iteration(NULL, TRUE);
-            g_source_remove(timeout_wait_id);
+            if (!is_timeout)
+                g_source_remove(timeout_wait_id);
         }
     }
 
@@ -650,9 +647,8 @@ read_from_io_channel (GIOChannel *channel, GCutEgg *egg, guint signal)
 }
 
 static gboolean
-watch_output (GIOChannel *source, GIOCondition condition, gpointer user_data)
+watch_common (GIOChannel *source, GIOCondition condition, WatchOutputData *data)
 {
-    WatchOutputData *data = user_data;
     gboolean keep_callback = TRUE;
 
     if (condition & (G_IO_IN | G_IO_PRI)) {
@@ -678,6 +674,40 @@ watch_output (GIOChannel *source, GIOCondition condition, gpointer user_data)
     return keep_callback;
 }
 
+static gboolean
+watch_output (GIOChannel *source, GIOCondition condition, gpointer user_data)
+{
+    WatchOutputData *data = user_data;
+    gboolean keep_callback = TRUE;
+
+    keep_callback = watch_common(source, condition, user_data);
+
+    if (!keep_callback) {
+        GCutEggPrivate *priv;
+        priv = GCUT_EGG_GET_PRIVATE(data->egg);
+        priv->output_watch_id = 0;
+    }
+
+    return keep_callback;
+}
+
+static gboolean
+watch_error (GIOChannel *source, GIOCondition condition, gpointer user_data)
+{
+    WatchOutputData *data = user_data;
+    gboolean keep_callback = TRUE;
+
+    keep_callback = watch_common(source, condition, user_data);
+
+    if (!keep_callback) {
+        GCutEggPrivate *priv;
+        priv = GCUT_EGG_GET_PRIVATE(data->egg);
+        priv->error_watch_id = 0;
+    }
+
+    return keep_callback;
+}
+
 gboolean
 gcut_egg_hatch (GCutEgg *egg, GError **error)
 {
@@ -747,7 +777,7 @@ gcut_egg_hatch (GCutEgg *egg, GError **error)
         priv->watch_error_data->signal = signals[ERROR_RECEIVED];
         priv->error = create_input_channel(error_fd,
                                            &(priv->error_watch_id),
-                                           watch_output,
+                                           watch_error,
                                            priv->watch_error_data);
     }
 
@@ -841,7 +871,8 @@ gcut_egg_wait (GCutEgg *egg, guint timeout, GError **error)
     timeout_id = g_timeout_add(timeout, cb_timeout_wait, &is_timeout);
     while (!is_timeout && priv->pid > 0)
         g_main_context_iteration(NULL, TRUE);
-    g_source_remove(timeout_id);
+    if (!is_timeout)
+        g_source_remove(timeout_id);
 
     if (is_timeout) {
         gchar *command;
