@@ -1,6 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  *  Copyright (C) 2008  g新部 Hiroyuki Ikezoe  <poincare@ikezoe.net>
+ *  Copyright (C) 2009-2013  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,7 +19,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <cutter/config.h>
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <stdlib.h>
@@ -86,6 +87,8 @@ static gchar   *get_error_results        (CutReport   *report);
 static gchar   *get_failure_results      (CutReport   *report);
 static gchar   *get_pending_results      (CutReport   *report);
 static gchar   *get_notification_results (CutReport   *report);
+static gchar   *get_omission_results     (CutReport   *report);
+static gchar   *get_crash_results        (CutReport   *report);
 static gchar   *get_test_result          (CutReport   *report,
                                           const gchar *test_name);
 
@@ -111,6 +114,8 @@ class_init (CutXMLReportClass *klass)
     report_class->get_failure_results      = get_failure_results;
     report_class->get_pending_results      = get_pending_results;
     report_class->get_notification_results = get_notification_results;
+    report_class->get_omission_results     = get_omission_results;
+    report_class->get_crash_results        = get_crash_results;
     report_class->get_test_result          = get_test_result;
 
     spec = g_param_spec_object("cut-run-context",
@@ -341,12 +346,6 @@ cb_complete_test_suite (CutRunContext *run_context, CutTestSuite *test_suite,
     output_to_file(report, "</report>");
 }
 
-static void
-cb_crashed (CutRunContext *run_context, const gchar *backtrace,
-            CutXMLReport *report)
-{
-}
-
 static void
 connect_to_run_context (CutXMLReport *report, CutRunContext *run_context)
 {
@@ -366,13 +365,13 @@ connect_to_run_context (CutXMLReport *report, CutRunContext *run_context)
     CONNECT_TO_TEST(error_test);
     CONNECT_TO_TEST(pending_test);
     CONNECT_TO_TEST(notification_test);
+    CONNECT_TO_TEST(omission_test);
+    CONNECT_TO_TEST(crash_test);
 
     CONNECT(complete_test);
     CONNECT(complete_test_case);
     CONNECT(complete_test_suite);
 
-    CONNECT(crashed);
-
 #undef CONNECT
 }
 
@@ -392,8 +391,6 @@ disconnect_from_run_context (CutXMLReport *report, CutRunContext *run_context)
     DISCONNECT(complete_test_case);
     DISCONNECT(complete_test_suite);
 
-    DISCONNECT(crashed);
-
     g_signal_handlers_disconnect_by_func(run_context,
                                          G_CALLBACK(cb_test_signal),
                                          report);
@@ -408,7 +405,7 @@ attach_to_run_context (CutListener *listener,
     CutXMLReport *report = CUT_XML_REPORT(listener);
     if (report->run_context)
         detach_from_run_context(listener, report->run_context);
-    
+
     if (run_context) {
         report->run_context = g_object_ref(run_context);
         connect_to_run_context(CUT_XML_REPORT(listener), run_context);
@@ -497,6 +494,18 @@ get_notification_results (CutReport *report)
     return get_status_results(CUT_XML_REPORT(report), CUT_TEST_RESULT_NOTIFICATION);
 }
 
+static gchar *
+get_omission_results (CutReport *report)
+{
+    return get_status_results(CUT_XML_REPORT(report), CUT_TEST_RESULT_OMISSION);
+}
+
+static gchar *
+get_crash_results (CutReport *report)
+{
+    return get_status_results(CUT_XML_REPORT(report), CUT_TEST_RESULT_CRASH);
+}
+
 static gchar *
 get_test_result (CutReport *report, const gchar *test_name)
 {
