@@ -1,6 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  *  Copyright (C) 2008  g新部 Hiroyuki Ikezoe  <poincare@ikezoe.net>
+ *  Copyright (C) 2011-2013  Kouhei Sutou  <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,7 +19,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <cutter/config.h>
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <stdlib.h>
@@ -34,6 +35,7 @@
 #include <cutter/cut-test-result.h>
 #include <cutter/cut-enum-types.h>
 #include <cutter/cut-utils.h>
+#include <cutter/cut-glib-compatible.h>
 
 #define CUT_TYPE_XML_STREAM            cut_type_xml_stream
 #define CUT_XML_STREAM(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), CUT_TYPE_XML_STREAM, CutXMLStream))
@@ -92,12 +94,10 @@ class_init (CutXMLStreamClass *klass)
 {
     GObjectClass *gobject_class;
     GParamSpec *spec;
-    CutStreamClass *stream_class;
 
     parent_class = g_type_class_peek_parent(klass);
 
     gobject_class = G_OBJECT_CLASS(klass);
-    stream_class = CUT_STREAM_CLASS(klass);
 
     gobject_class->dispose      = dispose;
     gobject_class->set_property = set_property;
@@ -693,23 +693,6 @@ cb_complete_run (CutRunContext *run_context, gboolean success,
     g_string_free(string, TRUE);
 }
 
-static void
-cb_crashed (CutRunContext *run_context, const gchar *backtrace,
-            CutXMLStream *stream)
-{
-    GString *string;
-
-    string = g_string_new(NULL);
-
-    g_string_append(string, "  <crashed>\n");
-    cut_utils_append_xml_element_with_value(string, 4, "backtrace", backtrace);
-    g_string_append(string, "  </crashed>\n");
-
-    flow(stream, "%s", string->str);
-
-    g_string_free(string, TRUE);
-}
-
 static void
 connect_to_run_context (CutXMLStream *stream, CutRunContext *run_context)
 {
@@ -746,6 +729,7 @@ connect_to_run_context (CutXMLStream *stream, CutRunContext *run_context)
     CONNECT_TO_TEST(pending);
     CONNECT_TO_TEST(notification);
     CONNECT_TO_TEST(omission);
+    CONNECT_TO_TEST(crash);
 
     CONNECT_TO_TEST_ITERATOR(success);
     CONNECT_TO_TEST_ITERATOR(failure);
@@ -753,6 +737,7 @@ connect_to_run_context (CutXMLStream *stream, CutRunContext *run_context)
     CONNECT_TO_TEST_ITERATOR(pending);
     CONNECT_TO_TEST_ITERATOR(notification);
     CONNECT_TO_TEST_ITERATOR(omission);
+    CONNECT_TO_TEST_ITERATOR(crash);
 
     CONNECT_TO_TEST_CASE(success);
     CONNECT_TO_TEST_CASE(failure);
@@ -760,6 +745,7 @@ connect_to_run_context (CutXMLStream *stream, CutRunContext *run_context)
     CONNECT_TO_TEST_CASE(pending);
     CONNECT_TO_TEST_CASE(notification);
     CONNECT_TO_TEST_CASE(omission);
+    CONNECT_TO_TEST_CASE(crash);
 
     CONNECT(complete_test);
     CONNECT(complete_iterated_test);
@@ -768,8 +754,6 @@ connect_to_run_context (CutXMLStream *stream, CutRunContext *run_context)
     CONNECT(complete_test_suite);
     CONNECT(complete_run);
 
-    CONNECT(crashed);
-
 #undef CONNECT
 }
 
@@ -812,8 +796,6 @@ disconnect_from_run_context (CutXMLStream *stream,
     DISCONNECT(complete_test_suite);
     DISCONNECT(complete_run);
 
-    DISCONNECT(crashed);
-
 #undef DISCONNECT
 }
 
