@@ -1,4 +1,21 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/*
+ *  Copyright (C) 2008-2013  Kouhei Sutou <kou@clear-code.com>
+ *
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ */
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -8,6 +25,7 @@
 #include <gcutter.h>
 #include <cutter/cut-pipeline.h>
 #include <cutter/cut-runner.h>
+#include <cutter/cut-glib-compatible.h>
 
 #include "../lib/cuttest-assertions.h"
 
@@ -135,7 +153,8 @@ data_signal (void)
                  signal_test_data_free,
                  "omission",
                  signal_test_data_new("omission", TRUE),
-                 signal_test_data_free);
+                 signal_test_data_free,
+                 NULL);
 }
 
 static void
@@ -207,7 +226,8 @@ data_count (void)
     get_count = cut_run_context_get_n_ ## result_plural;                \
     cut_add_data(#result,                                               \
                  count_test_data_new(#result, get_count, success),      \
-                 count_test_data_free);                                 \
+                 count_test_data_free,                                  \
+                 NULL);                                                 \
 } while (0)
 
     ADD_DATA(success, successes, TRUE);
