@@ -1,3 +1,22 @@
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/*
+ *  Copyright (C) 2008-2012  Kouhei Sutou <kou@clear-code.com>
+ *
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ */
+
 #include <gcutter.h>
 #include <cutter/cut-test-iterator.h>
 #include <cutter/cut-test-runner.h>
@@ -38,6 +57,11 @@ static gint fail_line;
 } while (0)
 
 #define FAIL_LOCATION (cut_take_printf("%s:%d", __FILE__, fail_line))
+#ifdef __clang__
+#  define FUNCTION(name) "void " name "(gconstpointer)"
+#else
+#  define FUNCTION(name) name
+#endif
 
 
 static void
@@ -295,7 +319,8 @@ stub_iterated_data (void)
 {
     cut_add_data("First", GINT_TO_POINTER(1), NULL,
                  "Second", GINT_TO_POINTER(2), NULL,
-                 "Third", GINT_TO_POINTER(3), NULL);
+                 "Third", GINT_TO_POINTER(3), NULL,
+		 NULL);
 }
 
 static void
@@ -353,19 +378,22 @@ test_failure (void)
                            NULL,
                            "<2 == GPOINTER_TO_INT(data)>",
                            "2", "1",
-                           FAIL_LOCATION, "stub_failure_iterated_test",
+                           FAIL_LOCATION,
+                           FUNCTION("stub_failure_iterated_test"),
                            NULL);
     cut_assert_test_result(run_context, 1, CUT_TEST_RESULT_SUCCESS,
                            "failure test iterator (Second)",
                            NULL, NULL,
                            NULL, NULL,
+                           NULL,
                            NULL);
     cut_assert_test_result(run_context, 2, CUT_TEST_RESULT_FAILURE,
                            "failure test iterator (Third)",
                            NULL,
                            "<2 == GPOINTER_TO_INT(data)>",
                            "2", "3",
-                           FAIL_LOCATION, "stub_failure_iterated_test",
+                           FAIL_LOCATION,
+                           FUNCTION("stub_failure_iterated_test"),
                            NULL);
 }
 
@@ -397,18 +425,21 @@ test_error (void)
                            "error test iterator (First)",
                            NULL, NULL,
                            NULL, NULL,
+                           NULL,
                            NULL);
     cut_assert_test_result(run_context, 1, CUT_TEST_RESULT_ERROR,
                            "error test iterator (Second)",
                            "ERROR!",
                            NULL,
                            NULL, NULL,
-                           FAIL_LOCATION, "stub_error_iterated_test",
+                           FAIL_LOCATION,
+                           FUNCTION("stub_error_iterated_test"),
                            NULL);
     cut_assert_test_result(run_context, 2, CUT_TEST_RESULT_SUCCESS,
                            "error test iterator (Third)",
                            NULL, NULL,
                            NULL, NULL,
+                           NULL,
                            NULL);
 }
 
@@ -440,18 +471,21 @@ test_pending (void)
                            "pending test iterator (First)",
                            NULL, NULL,
                            NULL, NULL,
+                           NULL,
                            NULL);
     cut_assert_test_result(run_context, 1, CUT_TEST_RESULT_PENDING,
                            "pending test iterator (Second)",
                            "PENDING!",
                            NULL,
                            NULL, NULL,
-                           FAIL_LOCATION, "stub_pending_iterated_test",
+                           FAIL_LOCATION,
+                           FUNCTION("stub_pending_iterated_test"),
                            NULL);
     cut_assert_test_result(run_context, 2, CUT_TEST_RESULT_SUCCESS,
                            "pending test iterator (Third)",
                            NULL, NULL,
                            NULL, NULL,
+                           NULL,
                            NULL);
 }
 
@@ -483,23 +517,27 @@ test_notification (void)
                            "notification test iterator (First)",
                            NULL, NULL,
                            NULL, NULL,
+                           NULL,
                            NULL);
     cut_assert_test_result(run_context, 1, CUT_TEST_RESULT_NOTIFICATION,
                            "notification test iterator (Second)",
                            "NOTIFICATION!",
                            NULL,
                            NULL, NULL,
-                           FAIL_LOCATION, "stub_notification_iterated_test",
+                           FAIL_LOCATION,
+                           FUNCTION("stub_notification_iterated_test"),
                            NULL);
     cut_assert_test_result(run_context, 2, CUT_TEST_RESULT_SUCCESS,
                            "notification test iterator (Second)",
                            NULL, NULL,
                            NULL, NULL,
+                           NULL,
                            NULL);
     cut_assert_test_result(run_context, 3, CUT_TEST_RESULT_SUCCESS,
                            "notification test iterator (Third)",
                            NULL, NULL,
                            NULL, NULL,
+                           NULL,
                            NULL);
 }
 
@@ -531,33 +569,40 @@ test_omission (void)
                            "omission test iterator (First)",
                            NULL, NULL,
                            NULL, NULL,
+                           NULL,
                            NULL);
     cut_assert_test_result(run_context, 1, CUT_TEST_RESULT_OMISSION,
                            "omission test iterator (Second)",
                            "OMISSION!",
                            NULL,
                            NULL, NULL,
-                           FAIL_LOCATION, "stub_omission_iterated_test",
+                           FAIL_LOCATION,
+                           FUNCTION("stub_omission_iterated_test"),
                            NULL);
     cut_assert_test_result(run_context, 2, CUT_TEST_RESULT_SUCCESS,
                            "omission test iterator (Second)",
                            NULL, NULL,
                            NULL, NULL,
+                           NULL,
                            NULL);
     cut_assert_test_result(run_context, 3, CUT_TEST_RESULT_SUCCESS,
                            "omission test iterator (Third)",
                            NULL, NULL,
                            NULL, NULL,
+                           NULL,
                            NULL);
 }
 
 static void
 stub_error_in_data_setup_iterated_data (void)
 {
-    cut_add_data("First", GINT_TO_POINTER(1), NULL);
-    cut_add_data("Second", GINT_TO_POINTER(2), NULL);
+    cut_add_data("First", GINT_TO_POINTER(1), NULL,
+		 NULL);
+    cut_add_data("Second", GINT_TO_POINTER(2), NULL,
+		 NULL);
     cut_error("error in data setup");
-    cut_add_data("Third", GINT_TO_POINTER(3), NULL);
+    cut_add_data("Third", GINT_TO_POINTER(3), NULL,
+                 NULL);
 }
 
 static void
