@@ -14,6 +14,8 @@ void test_get_backtrace(void);
 void test_status_to_signal_name(void);
 void test_status_is_critical(void);
 void test_get_test_suite(void);
+void test_get_diff(void);
+void test_set_diff(void);
 void test_to_xml_empty(void);
 void test_to_xml_empty_failure(void);
 void test_new_from_xml(void);
@@ -110,12 +112,28 @@ test_get_message_full (void)
                                  "user-message",
                                  "system-message",
                                  backtrace);
-    cut_assert_equal_string("user-message\nsystem-message",
+    cut_assert_equal_string("user-message\n"
+                            "system-message",
                             cut_test_result_get_message(result));
     cut_assert_equal_string("user-message",
                             cut_test_result_get_user_message(result));
     cut_assert_equal_string("system-message",
                             cut_test_result_get_system_message(result));
+
+    cut_test_result_set_expected(result, "a\nb\nc");
+    cut_test_result_set_actual(result, "a\nB\nc");
+
+    cut_assert_equal_string("user-message\n"
+                            "system-message\n"
+                            "expected: <a\nb\nc>\n"
+                            "  actual: <a\nB\nc>\n"
+                            "\n"
+                            "diff:\n"
+                            "  a\n"
+                            "- b\n"
+                            "+ B\n"
+                            "  c",
+                            cut_test_result_get_message(result));
 }
 
 void
@@ -321,6 +339,56 @@ test_get_test_suite (void)
     cut_assert_null(cut_test_result_get_test_suite(result));
 }
 
+void
+test_get_diff (void)
+{
+    result = cut_test_result_new_empty();
+    cut_assert_equal_string(NULL, cut_test_result_get_expected(result));
+    cut_assert_equal_string(NULL, cut_test_result_get_actual(result));
+    cut_assert_equal_string(NULL, cut_test_result_get_diff(result));
+    cut_assert_equal_string(NULL, cut_test_result_get_folded_diff(result));
+
+    cut_test_result_set_expected(result, "a\nb\nc");
+    cut_assert_equal_string(NULL, cut_test_result_get_diff(result));
+    cut_assert_equal_string(NULL, cut_test_result_get_folded_diff(result));
+
+    cut_test_result_set_actual(result, "a\nB\nc");
+    cut_assert_equal_string("  a\n"
+                            "- b\n"
+                            "+ B\n"
+                            "  c",
+                            cut_test_result_get_diff(result));
+    cut_assert_equal_string(NULL, cut_test_result_get_folded_diff(result));
+
+    cut_test_result_set_actual(result, "a\nX\nc");
+    cut_assert_equal_string("  a\n"
+                            "- b\n"
+                            "+ X\n"
+                            "  c",
+                            cut_test_result_get_diff(result));
+    cut_assert_equal_string(NULL, cut_test_result_get_folded_diff(result));
+}
+
+void
+test_set_diff (void)
+{
+    const gchar diff[] =
+        "  A\n"
+        "- B\n"
+        "+ b\n"
+        "  C";
+
+    result = cut_test_result_new_empty();
+    cut_test_result_set_diff(result, diff);
+
+    cut_test_result_set_expected(result, "a\nb\nc");
+    cut_assert_equal_string(diff, cut_test_result_get_diff(result));
+    cut_assert_equal_string(NULL, cut_test_result_get_folded_diff(result));
+    cut_test_result_set_actual(result, "a\nB\nc");
+    cut_assert_equal_string(diff, cut_test_result_get_diff(result));
+    cut_assert_equal_string(NULL, cut_test_result_get_folded_diff(result));
+}
+
 void
 test_to_xml_empty (void)
 {
@@ -408,7 +476,7 @@ test_new_from_xml (void)
     cut_assert_equal_string("test-cut-report-xml.c",
                             cut_backtrace_entry_get_file(entry));
     cut_assert_equal_uint(31, cut_backtrace_entry_get_line(entry));
-    cut_assert_equal_string("stub_error_test",
+    cut_assert_equal_string("stub_error_test()",
                             cut_backtrace_entry_get_function(entry));
 
     cut_assert_not_null(g_list_next(actual_backtrace));
@@ -416,7 +484,7 @@ test_new_from_xml (void)
     cut_assert_equal_string("test-cut-test-result.c",
                             cut_backtrace_entry_get_file(entry));
     cut_assert_equal_uint(29, cut_backtrace_entry_get_line(entry));
-    cut_assert_equal_string("test_new_from_xml",
+    cut_assert_equal_string("test_new_from_xml()",
                             cut_backtrace_entry_get_function(entry));
     cut_assert_equal_string("additional info",
                             cut_backtrace_entry_get_info(entry));
