@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include "config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <glib.h>
@@ -174,6 +174,38 @@ pass_assertion_info_free (CuttestPassAssertionInfo *info)
     g_slice_free(CuttestPassAssertionInfo, info);
 }
 
+static CuttestFailureTestInfo *
+failure_test_info_new (CutTest *test, CutTestContext *test_context,
+                       CutTestResult *test_result)
+{
+    CuttestFailureTestInfo *info;
+
+    info = g_slice_new(CuttestFailureTestInfo);
+    info->test = test;
+    if (info->test)
+        g_object_ref(info->test);
+    info->test_context = test_context;
+    if (info->test_context)
+        g_object_ref(info->test_context);
+    info->test_result = test_result;
+    if (info->test_result)
+        g_object_ref(info->test_result);
+
+    return info;
+}
+
+static void
+failure_test_info_free (CuttestFailureTestInfo *info)
+{
+    if (info->test)
+        g_object_unref(info->test);
+    if (info->test_context)
+        g_object_unref(info->test_context);
+    if (info->test_result)
+        g_object_unref(info->test_result);
+    g_slice_free(CuttestFailureTestInfo, info);
+}
+
 static CuttestCompleteIteratedTestInfo *
 complete_iterated_test_info_new (CutIteratedTest *iterated_test,
                                  CutTestContext *test_context,
@@ -299,6 +331,13 @@ dispose (GObject *object)
         receiver->pass_assertions = NULL;
     }
 
+    if (receiver->failure_tests) {
+        g_list_foreach(receiver->failure_tests,
+                       (GFunc)failure_test_info_free, NULL);
+        g_list_free(receiver->failure_tests);
+        receiver->failure_tests = NULL;
+    }
+
     if (receiver->complete_iterated_tests) {
         g_list_foreach(receiver->complete_iterated_tests,
                        (GFunc)complete_iterated_test_info_free, NULL);
@@ -339,12 +378,6 @@ dispose (GObject *object)
         receiver->complete_runs = NULL;
     }
 
-    if (receiver->crasheds) {
-        g_list_foreach(receiver->crasheds, (GFunc)g_free, NULL);
-        g_list_free(receiver->crasheds);
-        receiver->crasheds = NULL;
-    }
-
     G_OBJECT_CLASS(cuttest_event_receiver_parent_class)->dispose(object);
 }
 
@@ -461,6 +494,19 @@ pass_assertion (CutRunContext *context, CutTest *test,
     receiver->pass_assertions = g_list_append(receiver->pass_assertions, info);
 }
 
+static void
+failure_test (CutRunContext *context, CutTest *test,
+              CutTestContext *test_context,
+              CutTestResult *test_result)
+{
+    CuttestEventReceiver *receiver;
+    CuttestFailureTestInfo *info;
+
+    receiver = CUTTEST_EVENT_RECEIVER(context);
+    info = failure_test_info_new(test, test_context, test_result);
+    receiver->failure_tests = g_list_append(receiver->failure_tests, info);
+}
+
 static void
 complete_iterated_test (CutRunContext *context, CutIteratedTest *iterated_test,
                         CutTestContext *test_context, gboolean success)
@@ -532,15 +578,6 @@ complete_run (CutRunContext *context, gboolean success)
                                             GINT_TO_POINTER(success));
 }
 
-static void
-crashed (CutRunContext *context, const gchar *backtrace)
-{
-    CuttestEventReceiver *receiver;
-
-    receiver = CUTTEST_EVENT_RECEIVER(context);
-    receiver->crasheds = g_list_append(receiver->crasheds, g_strdup(backtrace));
-}
-
 static void
 cuttest_event_receiver_class_init (CuttestEventReceiverClass *klass)
 {
@@ -562,13 +599,13 @@ cuttest_event_receiver_class_init (CuttestEventReceiverClass *klass)
     run_context_class->start_test = start_test;
     run_context_class->start_iterated_test = start_iterated_test;
     run_context_class->pass_assertion = pass_assertion;
+    run_context_class->failure_test = failure_test;
     run_context_class->complete_iterated_test = complete_iterated_test;
     run_context_class->complete_test = complete_test;
     run_context_class->complete_test_iterator = complete_test_iterator;
     run_context_class->complete_test_case = complete_test_case;
     run_context_class->complete_test_suite = complete_test_suite;
     run_context_class->complete_run = complete_run;
-    run_context_class->crashed = crashed;
 }
 
 static void
@@ -589,7 +626,6 @@ cuttest_event_receiver_init (CuttestEventReceiver *receiver)
     receiver->complete_test_cases = NULL;
     receiver->complete_test_suites = NULL;
     receiver->complete_runs = NULL;
-    receiver->crasheds = NULL;
 }
 
 CutRunContext *
